==> japhar-0.06.tar.gz: japhar-0.06/include/native-threads.h <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   native-threads.h -- API for native threads and monitors.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#ifndef _native_threads_h
#define _native_threads_h

#include "jni.h"

#ifdef __cplusplus
extern "C" {
#endif

/* These should mirror the constants set in the java Thread class */
#define JTHR_MAX_PRIORITY 10
#define JTHR_MIN_PRIORITY 1
#define JTHR_DEFAULT_PRIORITY 5

typedef void* HThread;

extern HThread THREAD_start(void *(*start_function)(void*),
			    void *start_arg,
			    int priority,
			    int initialStackSize);

extern void THREAD_setPriority(HThread thread, int priority);
extern void THREAD_exit();

extern int THREAD_delete(HThread thread);

extern void THREAD_yield();
extern void THREAD_sleep(jlong);

extern void THREAD_suspend(HThread thread);
extern void THREAD_resume(HThread thread);

extern HThread THREAD_getCurrent();

extern void THREAD_setEnv(JNIEnv *env);
extern void THREAD_setVM(JavaVM *vm);
extern JNIEnv *THREAD_getEnv();
extern JavaVM *THREAD_getVM();

extern void THREAD_setJavaInfo(void *info);
extern void *THREAD_getJavaInfo();


typedef struct MonitorStruct* HMonitor;

extern HMonitor MONITOR_create();
extern void MONITOR_destroy(HMonitor mon);
extern void MONITOR_enter(HMonitor mon);
/* Return 1 on success and 0 if current thread don't own the monitor */
extern int MONITOR_exit(HMonitor mon);
extern int MONITOR_wait(HMonitor mon);
extern int MONITOR_timedWait(HMonitor mon, jlong time_to_wait);
extern int MONITOR_notifyOne(HMonitor mon);
extern int MONITOR_notifyAll(HMonitor mon);

extern HMonitor MONITOR_getForObject(jobject obj);

#ifdef __cplusplus
};
#endif

#endif /* _native_threads_h */

==> japhar-0.07.tar.gz: japhar-0.07/include/native-threads.h <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   native-threads.h -- API for native threads and monitors.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#ifndef _native_threads_h
#define _native_threads_h

#include "jni.h"

#ifdef __cplusplus
extern "C" {
#endif

/* These should mirror the constants set in the java Thread class */
#define JTHR_MAX_PRIORITY 10
#define JTHR_MIN_PRIORITY 1
#define JTHR_DEFAULT_PRIORITY 5

typedef void* HThread;

extern HThread THREAD_start(void *(*start_function)(void*),
			    void *start_arg,
			    int priority,
			    int initialStackSize);

extern void THREAD_setPriority(HThread thread, int priority);
extern void THREAD_exit(void);

extern int THREAD_delete(HThread thread);

extern void THREAD_yield(void);
extern void THREAD_sleep(jlong);

extern void THREAD_suspend(HThread thread);
extern void THREAD_resume(HThread thread);

extern HThread THREAD_getCurrent(void);

extern void THREAD_setEnv(JNIEnv *env);
extern void THREAD_setVM(JavaVM *vm);
extern JNIEnv *THREAD_getEnv(void);
extern JavaVM *THREAD_getVM(void);

extern void THREAD_setJavaInfo(void *info);
extern void *THREAD_getJavaInfo(void);


typedef struct MonitorStruct* HMonitor;

extern HMonitor MONITOR_create(void);
extern void MONITOR_destroy(HMonitor mon);
extern void MONITOR_enter(HMonitor mon);
/* Return 1 on success and 0 if current thread don't own the monitor */
extern int MONITOR_exit(HMonitor mon);
extern int MONITOR_wait(HMonitor mon);
extern int MONITOR_timedWait(HMonitor mon, jlong time_to_wait);
extern int MONITOR_notifyOne(HMonitor mon);
extern int MONITOR_notifyAll(HMonitor mon);

extern HMonitor MONITOR_getForObject(jobject obj);

#ifdef __cplusplus
};
#endif

#endif /* _native_threads_h */
